@@ -1,5 +1,5 @@
 from typing import Optional, Sequence
-from datetime import date
+from datetime import date, datetime
 from pydantic import BaseModel
 
 from nav_dcat import doc_fields
@@ -12,6 +12,15 @@ class ESDocument(BaseModel):
     type: doc_fields.Type
     uri: str
     format: Optional[doc_fields.Type]
+    modified: Optional[str] = datetime.now().isoformat()
+    issued: Optional[str] = datetime.now().isoformat()
+    periodicity: Optional[str] = ""
+    provenance: Optional[str] = ""
+    contactpoint: Optional[str] = ""
+    author: Optional[str] = ""
+    repo: Optional[str] = ""
+    readme: Optional[str] = ""
+    spatial: Optional[str] = ""
     accessRights: Optional[doc_fields.AccessRights] = doc_fields.AccessRights.INTERNAL.value
     pii: Optional[doc_fields.Pii] = doc_fields.Pii.FALSE.value
     keyword: Optional[Sequence] = []
